@@ -1,4 +1,4 @@
-from azure.storage.blob import BlobServiceClient, BlobClient, ContainerClient, generate_blob_sas, BlobSasPermissions
+from azure.storage.blob.sharedaccesssignature import BlobSharedAccessSignature
 from datetime import datetime, timedelta
 import urllib.request, urllib.parse
 import json
@@ -21,16 +21,15 @@ class dataflow_reader(object):
         self._storage_account_key = storage_account_key
         self._folder_name = "{}/{}".format(pbi_workspace_name, dataflow_name)
         # read only
-        self._sas_permissions = BlobSasPermissions(read=True)
+        self._sas_permissions = "r"
         self._expiry_in_minutes = expiry_in_minutes
 
     def get_blob_sas(self, blob_name):
         start_time = datetime.utcnow() - timedelta(minutes=5)
         expiration_time = datetime.utcnow() + timedelta(minutes=self._expiry_in_minutes)
-        return generate_blob_sas(self._storage_account_name, 
-            self._container_name, 
+        sas_generator = BlobSharedAccessSignature(self._storage_account_name, account_key = self._storage_account_key)
+        return sas_generator.generate_blob(self._container_name, 
             blob_name, 
-            account_key = self._storage_account_key, 
             expiry = expiration_time, 
             start = start_time,
             permission=self._sas_permissions)
